@@ -16,8 +16,8 @@ func IsRepo() bool {
 	return err == nil && strings.TrimSpace(out) == "true"
 }
 
-// RunEnv runs a git command with the specified env vars and returns its output or errors.
-func RunEnv(env map[string]string, args ...string) (string, error) {
+// Run runs a git command and returns its output or errors.
+func Run(args ...string) (string, error) {
 	// TODO: use exex.CommandContext here and refactor.
 	extraArgs := []string{
 		"-c", "log.showSignature=false",
@@ -26,13 +26,6 @@ func RunEnv(env map[string]string, args ...string) (string, error) {
 	/* #nosec */
 	cmd := exec.Command("git", args...)
 
-	if env != nil {
-		cmd.Env = []string{}
-		for k, v := range env {
-			cmd.Env = append(cmd.Env, k+"="+v)
-		}
-	}
-
 	stdout := bytes.Buffer{}
 	stderr := bytes.Buffer{}
 
@@ -53,11 +46,6 @@ func RunEnv(env map[string]string, args ...string) (string, error) {
 	return stdout.String(), nil
 }
 
-// Run runs a git command and returns its output or errors.
-func Run(args ...string) (string, error) {
-	return RunEnv(nil, args...)
-}
-
 // Clean the output.
 func Clean(output string, err error) (string, error) {
 	output = strings.ReplaceAll(strings.Split(output, "\n")[0], "'", "")
