@@ -47,11 +47,8 @@ func (Pipe) Run(ctx *context.Context) (err error) {
 	}
 
 	artifactList := ctx.Artifacts.Filter(filter).List()
-	if len(artifactList) == 0 {
-		return nil
-	}
 
-	extraFiles, err := extrafiles.Find(ctx.Config.Checksum.ExtraFiles)
+	extraFiles, err := extrafiles.Find(ctx, ctx.Config.Checksum.ExtraFiles)
 	if err != nil {
 		return err
 	}
@@ -64,6 +61,10 @@ func (Pipe) Run(ctx *context.Context) (err error) {
 		})
 	}
 
+	if len(artifactList) == 0 {
+		return nil
+	}
+
 	g := semerrgroup.New(ctx.Parallelism)
 	sumLines := make([]string, len(artifactList))
 	for i, artifact := range artifactList {
