@@ -20,11 +20,13 @@ import (
 type GitInfo struct {
 	Branch      string
 	CurrentTag  string
+	PreviousTag string
 	Commit      string
 	ShortCommit string
 	FullCommit  string
 	CommitDate  time.Time
 	URL         string
+	Summary     string
 }
 
 // Env is the environment variables.
